<?php
/*
 Plugin Name: yiid.it for WordPress
 Plugin URI: http://www.yiid.it/
 Description: Adds the yiid.it like/dislike button below each post
 Version: 0.8
 Author: pfefferle, weyandch
 Author URI: http://www.yiid.it/
 */

add_action('the_content', array('YiidIt', 'addToContent'), 21);
add_action('wp_head', array('YiidIt', 'addToHeader'), 21);

// Pre-2.6 compatibility
if ( ! defined( 'WP_CONTENT_URL' ) )
  define( 'WP_CONTENT_URL', get_option( 'siteurl' ) . '/wp-content' );
if ( ! defined( 'WP_CONTENT_DIR' ) )
  define( 'WP_CONTENT_DIR', ABSPATH . 'wp-content' );
if ( ! defined( 'WP_PLUGIN_URL' ) )
  define( 'WP_PLUGIN_URL', WP_CONTENT_URL. '/plugins' );
if ( ! defined( 'WP_PLUGIN_DIR' ) )
  define( 'WP_PLUGIN_DIR', WP_CONTENT_DIR . '/plugins' );
if ( ! defined( 'WP_ADMIN_URL' ) )
  define( 'WP_ADMIN_URL', get_option('siteurl') . '/wp-admin' );

// yiid.it consts
define( 'YIID_IT_SHOW_EVERYWHERE', 1 );
define( 'YIID_IT_SHOW_ON_SINGLE', 2 );

include_once('YiidItAdminPages.php');

/**
 * YiidItWidget Widget-Class
 */
class YiidIt {
  /**
   * adds the code to the content
   *
   * @param string $content
   * @return string
   */
  function addToContent($content) {
    $widgetCode = YiidIt::generateLikeButton();
    $staticCode = YiidIt::generateStaticButton();

    if (get_option('yiidit_button_position') == "top") {
      $contentWithButton = $widgetCode.$content;
    } else {
      $contentWithButton = $content.$widgetCode;
    }

    // display static-button in feed
    if (is_feed()) {
      if (get_option('yiidit_static_feed_button') == "show") {
        return $content . $staticCode;
      } else {
        return $content;
      }
    }

    // where to show
    $whereToShow = get_option('yiidit_show_on');
    if ((is_archive() || is_home() || is_author()) == true && $whereToShow['overviews'] == "show")
      return $contentWithButton;
    elseif (is_single() == true && $whereToShow['posts'] == "show")
      return $contentWithButton;
    elseif (is_page() == true && $whereToShow['pages'] == "show")
      return $contentWithButton;
    else
      return $content;
  }

  /**
   * adds microids to header
   */
  function addToHeader() {
    global $wpdb;

    $sql =  "SELECT user_email FROM $wpdb->users";
    $emails = $wpdb->get_results($wpdb->prepare($sql), ARRAY_A);

    $blogurl = get_bloginfo('wpurl');

    $hash = YiidIt::generateMicroid("mailto:".get_bloginfo('admin_email '), $blogurl);
    echo '<meta name="microid" content="mailto+http:sha1:' . $hash . '" />'."\n";

    foreach ($emails as $email) {
      $hash = YiidIt::generateMicroid("mailto:".$email['user_email'], $blogurl);
      echo '<meta name="microid" content="mailto+http:sha1:' . $hash . '" />'."\n";
    }
  }

	/**
	 * generates the like button
	 *
	 * @return string
	 */
	function generateLikeButton() {
		$widgetCode = '<p style="clear: both;">
                   <iframe scrolling="no" frameborder="0" marginwidth="0" marginheight="0"
                           style="overflow: hidden; '.YiidIt::generateSize().'"
                           src="http://widgets.yiid.com/w/like/'.YiidIt::getButtonMode().'?cult='.YiidIt::getButtonLang().'&type=like&url='.urlencode(get_permalink()).'&title='.urlencode(strip_tags(html_entity_decode(get_the_title()))).'&color='.urlencode(YiidIt::getButtonFontColor()).YiidIt::getSocial().'"
                           allowtransparency="true">
                   </iframe>
                   </p>';

		return $widgetCode;
	}

  /**
   * generates the like button
   *
   * @return string
   */
  function generateStaticButton() {
    $widgetCode = '<p style="clear: both;">
                   <a href="http://widgets.yiid.com/static/like?cult='.YiidIt::getButtonLang().'&type=like&url='.urlencode(get_permalink()).'&title='.urlencode(strip_tags(html_entity_decode(get_the_title()))).'">
                     <img src="http://yiid.it/img/global/yiid-btn-like-'.YiidIt::getButtonLang().'.png" alt="Like" />
                   </a>
                   </p>';

    return $widgetCode;
  }

	/**
	 * returns the button language
	 *
	 * @return string
	 */
	function getButtonLang() {
		if (get_option('yiidit_button_lang')) {
			return get_option('yiidit_button_lang');
		} else {
			return "en";
		}
	}

	/**
	 * returns button mode, like&dislike or like only
	 *
	 * @author weyandch
	 * @return string
	 */
	function getButtonMode() {
		if (get_option('yiidit_button_mode') == 'like') {
			return 'like.php';
		} else {
			return "full.php";
		}
	}

	/**
	 * returns button font color
	 *
	 * @author weyandch
	 * @return string
	 */
	function getButtonFontColor() {
		if (get_option('yiidit_button_color')) {
			return get_option('yiidit_button_color');
		} else {
			return '#000000';
		}
	}

 /**
   * returns button font color
   *
   * @author weyandch
   * @return string
   */
  function getSocial() {
    if (get_option('yiidit_button_social')) {
      return "&social=".get_option('yiidit_button_social');
    } else {
      return "&social=0";
    }
  }

  function generateSize() {
    if (YiidIt::getSocial()) {
      return "width: 420px; height: 62px;";
    } else {
      return "width: 400px; height: 30px;";
    }
  }

  function generateMicroid($firstUri, $secondUri) {
    $firstUriHash = sha1($firstUri);
    $secondUriHash = sha1($secondUri);

    return sha1($firstUriHash . $secondUriHash);
  }
}
?>